package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.RmsCarDriverMapper;
import com.steerinfo.dil.model.RmsCarDriver;
import com.steerinfo.dil.model.RmsCarrier;
import com.steerinfo.dil.service.IRmsCarDriverService;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.framework.utils.misc.IdGenerator;
import com.steerinfo.framework.utils.upload.UploadUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:ZhouZhou
 * @CreateTime:2021/11/6 9:56
 * @Version:V1.0
 */


@Service(value = "rmsCarDriverService")
public class RmsCarDriverServiceImpl implements IRmsCarDriverService {
    @Autowired
    private RmsCarDriverMapper rmsCarDriverMapper;

    /*
    * 展现司机信息
    * */
    public List<Map<String, Object>> getCarDriverList(Map<String, Object> mapVal) {
        return rmsCarDriverMapper.getCarDriverList(mapVal);
    }

/*
* 根据id删除
* */
    @Override
    public int deleteCarDriver(BigDecimal id) {
        RmsCarDriver rmsCarDriver=rmsCarDriverMapper.selectByPrimaryKey(id);
        rmsCarDriver.setDeleted(new BigDecimal(1));
        return rmsCarDriverMapper.updateByPrimaryKeySelective(rmsCarDriver);
    }

/*
* 更新操作
* */
    @Override
    public int updateCarDriver(RmsCarDriver rmsCarDriver) {

        rmsCarDriver.setUpdateUsername("admin");
        rmsCarDriver.setUpdateTime(new Date());

      return  rmsCarDriverMapper.updateByPrimaryKeySelective(rmsCarDriver);
    }

 /*
 * 增加司机
 * */
    @Override
    public int insertCarDriver(Map<String,Object> mapValue) {
        BigDecimal carrierId=DataChange.dataToBigDecimal(mapValue.get("carrierIds"));
        String driverName=(String)mapValue.get("driverName");
        String driverSex=(String) mapValue.get("driverSex");
        BigDecimal driverAge=new BigDecimal((String) mapValue.get("driverAge"));
        String driverIdentityCardId=(String) mapValue.get("driverIdentityCard");
        String driverPhone=(String)  mapValue.get("driverPhone");
        BigDecimal transportTypeId=DataChange.dataToBigDecimal(mapValue.get("transportTypeId"));
        int i=0;
        int rmsCarDrivers=rmsCarDriverMapper.selectByIdentityCard(driverIdentityCardId);
        RmsCarDriver rmsCarDriver=new RmsCarDriver();
        if(rmsCarDrivers==0){
            rmsCarDriver.setDriverName(driverName);
            rmsCarDriver.setDriverSex(driverSex);
            rmsCarDriver.setDriverAge(driverAge);
            rmsCarDriver.setDriverIdentityCard(driverIdentityCardId);
            rmsCarDriver.setDriverPhone(driverPhone);
            rmsCarDriver.setTransportTypeId(transportTypeId);
            rmsCarDriver.setCarrierId(carrierId);
            rmsCarDriver.setInsertUsername("admin");
            rmsCarDriver.setInsertTime(new Date());
            rmsCarDriver.setDeleted(new BigDecimal(0));
            rmsCarDriver.setDriverId(rmsCarDriverMapper.selectCarDriverId());
            i+= rmsCarDriverMapper.insertSelective(rmsCarDriver);
        }else{
            i=-1;
        }
        return i;
    }

    /**
     * 根据id查询司机信息
     * @param id
     * @return
     */
    @Override
    public List<Map<String,Object>> getCarDriverById(BigDecimal id) {
        return rmsCarDriverMapper.getCarDriverById(id);
    }

    /*
    * 运输类型下拉框
    * */
    @Override
    public List<Map<String, Object>> getTransportTypeId() {
        return rmsCarDriverMapper.getTransportTypeId();
    }

    /*
    * 边输入边查承运商
    * */
    @Override
    public List<Map<String, Object>> getCarrierName(String state) {
        state = "%"+state+"%";
        return rmsCarDriverMapper.getCarrierName(state);
    }
    //
    @Override
    public int uploadPhoto(MultipartFile file, String str) {
        int result = 0;
//        根据str判断当前照片类型f
        String name = file.getName();
        Long workId = 0L;
        Long datacenterId = 0L;
        byte[] fileNames=null;
//        id自动生成器
        IdGenerator idGenerator = new IdGenerator(workId, datacenterId);
//        图片存储的地址
        String uploadPath = "C:/workspaces/stworkspace/image/";
//        图片名称默认为空
        String imagePath = str;
//        创建一个map用来存储四张照片的地址
        Map<String, Object> map=new HashMap<>();
        String FileNames = UploadUtils.uploadFile(file, idGenerator, uploadPath, imagePath);
        System.out.println(FileNames);
        //         判断照片是否能上传成功
        if (FileNames!=null){
            fileNames = UploadUtils.imageToByte(FileNames);
            map.put(str,fileNames);
//             将照片的二进制插入到数据库
            RmsCarDriver rmsCarDriver=new RmsCarDriver();
            rmsCarDriver.setDriverId(rmsCarDriverMapper.getMaxDriveId());
            if (map.get("行驶证")!=null){
                rmsCarDriver.setDriverPermitPhoto((String) map.get("行驶证"));
            }
            if (map.get("驾驶证")!=null){
                rmsCarDriver.setDriverLisencePhoto((String)map.get("驾驶证"));
            }
            if (map.get("运输证")!=null){
                rmsCarDriver.setDriverLisencePhoto((String)map.get("运输证"));
            }
            if(map.get("从业资格证")!=null){
                rmsCarDriver.setDriverLisencePhoto((String)map.get("从业资格证"));
            }
            result+=rmsCarDriverMapper.insertSelective(rmsCarDriver);
        }else{
            result=-1;
        }
        return result;
    }


}

